@@ -17,36 +17,37 @@
 #define _GNU_SOURCE 1
 #define _POSIX_PTHREAD_SEMANTICS 1
 #define _TANDEM_SOURCE 1
+#define HAVE_INFINITY 1
+#define HAVE_NAN 1
 #define RUBY_SYMBOL_EXPORT_BEGIN _Pragma("GCC visibility push(default)")
 #define RUBY_SYMBOL_EXPORT_END _Pragma("GCC visibility pop")
 #define HAVE_DIRENT_H 1
 #define HAVE__BOOL 1
 #define HAVE_STDBOOL_H 1
 #define HAVE_SYS_WAIT_H 1
-#define HAVE_LIMITS_H 1
-#define HAVE_SYS_FILE_H 1
-#define HAVE_SYS_IOCTL_H 1
-#define HAVE_SYS_SYSCALL_H 1
-#define HAVE_FCNTL_H 1
-#define HAVE_SYS_FCNTL_H 1
-#define HAVE_SYS_PARAM_H 1
-#define HAVE_SYS_SELECT_H 1
-#define HAVE_SYS_TIME_H 1
-#define HAVE_SYS_TIMES_H 1
-#define HAVE_PWD_H 1
-#define HAVE_GRP_H 1
 #define HAVE_A_OUT_H 1
-#define HAVE_UTIME_H 1
-#define HAVE_SYS_RESOURCE_H 1
+#define HAVE_GRP_H 1
+#define HAVE_FCNTL_H 1
 #define HAVE_FLOAT_H 1
 #define HAVE_IEEEFP_H 1
 #define HAVE_LANGINFO_H 1
+#define HAVE_LIMITS_H 1
 #define HAVE_LOCALE_H 1
-#define HAVE_TIME_H 1
+#define HAVE_PWD_H 1
+#define HAVE_SYS_FCNTL_H 1
+#define HAVE_SYS_FILE_H 1
+#define HAVE_SYS_IOCTL_H 1
+#define HAVE_SYS_PARAM_H 1
+#define HAVE_SYS_RESOURCE_H 1
+#define HAVE_SYS_SELECT_H 1
 #define HAVE_SYS_SOCKET_H 1
+#define HAVE_SYS_SYSCALL_H 1
+#define HAVE_SYS_TIME_H 1
+#define HAVE_SYS_TIMES_H 1
 #define HAVE_SYS_UIO_H 1
+#define HAVE_TIME_H 1
+#define HAVE_UTIME_H 1
 #define HAVE_GMP_H 1
-#define HAVE_LIBGMP 1
 #define HAVE_TYPEOF 1
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
@@ -55,7 +56,6 @@
 #define SIZEOF_LONG 8
 #define SIZEOF_LONG_LONG 8
 #define SIZEOF___INT64 0
-#define SIZEOF___INT128 16
 #define SIZEOF_OFF_T 8
 #define SIZEOF_VOIDP 8
 #define SIZEOF_FLOAT 4
@@ -117,7 +117,11 @@
 #define HAVE_VA_ARGS_MACRO 1
 #define NORETURN(x) __attribute__ ((noreturn)) x
 #define DEPRECATED(x) __attribute__ ((deprecated)) x
+#define DEPRECATED_BY(n,x) __attribute__ ((deprecated("by "#n))) x
+#define DEPRECATED_TYPE(mesg,x) x __attribute__ ((deprecated mesg))
 #define NOINLINE(x) __attribute__ ((noinline)) x
+#define WEAK(x) __attribute__ ((weak)) x
+#define HAVE_FUNC_WEAK 1
 #define FUNC_CDECL(x) __attribute__ ((cdecl)) x
 #define HAVE_ATTRIBUTE_FUNCTION_ALIAS 1
 #define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
@@ -127,6 +131,7 @@
 #define UNREACHABLE __builtin_unreachable()
 #define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
 #define RUBY_FUNCTION_NAME_STRING __func__
+#define ENUM_OVER_INT 1
 #define HAVE_DECL_SYS_NERR 1
 #define HAVE_DECL_GETENV 1
 #define SIZEOF_SIZE_T 8
@@ -173,12 +178,6 @@
 #define SIZEOF_INT64_T 8
 #define HAVE_UINT64_T 1
 #define SIZEOF_UINT64_T 8
-#define HAVE_INT128_T 1
-#define int128_t __int128
-#define SIZEOF_INT128_T SIZEOF___INT128
-#define HAVE_UINT128_T 1
-#define uint128_t unsigned __int128
-#define SIZEOF_UINT128_T SIZEOF_UNSIGNED___INT128
 #define HAVE_INTPTR_T 1
 #define SIZEOF_INTPTR_T 8
 #define HAVE_UINTPTR_T 1
@@ -194,6 +193,7 @@
 #define HAVE_CRYPT 1
 #define HAVE_DUP2 1
 #define HAVE_ERF 1
+#define HAVE_EXPLICIT_BZERO 1
 #define HAVE_FFS 1
 #define HAVE_FINITE 1
 #define HAVE_FLOCK 1
@@ -265,6 +265,8 @@
 #define HAVE_WRITEV 1
 #define HAVE_MEMRCHR 1
 #define HAVE_MEMMEM 1
+#define HAVE_MKFIFO 1
+#define HAVE_MKNOD 1
 #define HAVE_MKTIME 1
 #define HAVE_PIPE2 1
 #define HAVE_POLL 1
@@ -342,7 +344,12 @@
 #define HAVE_PTHREAD_CONDATTR_SETCLOCK 1
 #define HAVE_PTHREAD_CONDATTR_INIT 1
 #define HAVE_PTHREAD_SIGMASK 1
+#define HAVE_PTHREAD_SET_NAME_NP 1
 #define HAVE_PTHREAD_ATTR_INIT 1
+#define SET_CURRENT_THREAD_NAME(name) pthread_set_name_np(pthread_self(), name)
+#define SET_ANOTHER_THREAD_NAME(thid,name) pthread_set_name_np(thid, name)
+#define UCONTEXT_IN_SIGNAL_H 1
+#define DEFINE_MCONTEXT_PTR(mc, uc) mcontext_t *mc = &(uc)->uc_mcontext
 #define USE_ELF 1
 #define HAVE_ELF_ABI_H 1
 #define DLEXT_MAXLEN 3
