@@ -6,7 +6,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.3.") or
-    raise "ruby lib version (2.3.3) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.3.5) doesn't match executable version (#{RUBY_VERSION})"
 
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.3/alpha-openbsd")
   DESTDIR = '' unless defined? DESTDIR
@@ -15,8 +15,8 @@ module RbConfig
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "3"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "222"
-  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.3.3-no_ri_docs-bootstrap/bin/install -c '
+  CONFIG["PATCHLEVEL"] = "376"
+  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.3.5-no_ri_docs-bootstrap/bin/install -c '
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)23"
@@ -75,19 +75,19 @@ module RbConfig
   CONFIG["ENABLE_SHARED"] = "yes"
   CONFIG["DLDLIBS"] = " -lc"
   CONFIG["SOLIBS"] = "$(LIBS)"
-  CONFIG["LIBRUBYARG_SHARED"] = "-L$(libdir) -l$(RUBY_SO_NAME)"
-  CONFIG["LIBRUBYARG_STATIC"] = "-L$(libdir) -l$(RUBY_SO_NAME)-static"
+  CONFIG["LIBRUBYARG_SHARED"] = "-Wl,-rpath,$(libdir) -L$(libdir) -l$(RUBY_SO_NAME)"
+  CONFIG["LIBRUBYARG_STATIC"] = "-Wl,-rpath,$(libdir) -L$(libdir) -l$(RUBY_SO_NAME)-static"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.0.1"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.2.0"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = "-std=iso9899:1999"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration -Wdeprecated-declarations"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration -Wdeprecated-declarations -Wno-packed-bitfield-compat"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-fast-math"
   CONFIG["NULLCMD"] = ":"
@@ -107,8 +107,8 @@ module RbConfig
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = "LD_PRELOAD"
   CONFIG["LIBPATHENV"] = "LD_LIBRARY_PATH"
-  CONFIG["RPATHFLAG"] = ""
-  CONFIG["LIBPATHFLAG"] = " -L%s"
+  CONFIG["RPATHFLAG"] = " -Wl,-rpath,%1$-s"
+  CONFIG["LIBPATHFLAG"] = " -L%1$-s"
   CONFIG["LINK_SO"] = ""
   CONFIG["ASMEXT"] = "S"
   CONFIG["LIBEXT"] = "a"
@@ -136,9 +136,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.3.3-no_ri_docs-bootstrap/bin/install -c  -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.3.3-no_ri_docs-bootstrap/bin/install -c  -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.3.3-no_ri_docs-bootstrap/bin/install -c -s  -m 755"
+  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.3.5-no_ri_docs-bootstrap/bin/install -c  -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.3.5-no_ri_docs-bootstrap/bin/install -c  -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.3.5-no_ri_docs-bootstrap/bin/install -c -s  -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -172,22 +172,22 @@ module RbConfig
   CONFIG["NACL_SDK_VARIANT"] = ""
   CONFIG["NACL_SDK_ROOT"] = ""
   CONFIG["NACL_TOOLCHAIN"] = ""
-  CONFIG["target_os"] = "openbsd6.1"
+  CONFIG["target_os"] = "openbsd6.2"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "alpha"
-  CONFIG["target"] = "alpha-unknown-openbsd6.1"
-  CONFIG["host_os"] = "openbsd6.1"
+  CONFIG["target"] = "alpha-unknown-openbsd6.2"
+  CONFIG["host_os"] = "openbsd6.2"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "alpha"
-  CONFIG["host"] = "alpha-unknown-openbsd6.1"
+  CONFIG["host"] = "alpha-unknown-openbsd6.2"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd6.1"
+  CONFIG["build_os"] = "openbsd6.2"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "alpha"
-  CONFIG["build"] = "alpha-unknown-openbsd6.1"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.3.3"
+  CONFIG["build"] = "alpha-unknown-openbsd6.2"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.3.5"
   CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = " $(optflags) $(debugflags) $(warnflags)"
